<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Http\RedirectResponse;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Validator;
use Inertia\Inertia;
use Inertia\Response;

use App\Models\Product;
use App\Models\CarMake;
use App\Models\CarModel;
use App\Models\CarBodyStyle;
use Hamcrest\Type\IsInteger;

class ProductsController extends Controller
{
    /**
     * Show the All Products view.
     */
    public function show(Request $request): Response
    {
        $perPage = $request->input('per_page', 10);
        $products = Product::paginate($perPage);

        $carMakes = CarMake::orderby('name','asc')->get();
        $carModels = CarModel::orderby('name','asc')->get();
        $carBodyStyles = CarBodyStyle::orderby('name','asc')->get();

        return Inertia::render('Admin/Products/AllProducts', [
            'products' => $products,
            'carMakes' => $carMakes,
            'carModels' => $carModels,
            'carBodyStyles' => $carBodyStyles,
            'per_page' => $perPage,
        ]);
    }

    /**
     * Show the add product view.
     */
    public function add(Request $request): Response
    {
        $carMakes = CarMake::orderby('name','asc')->get();
        $carModels = CarModel::orderby('name','asc')->get();
        $carBodyStyles = CarBodyStyle::orderby('name','asc')->get();

        return Inertia::render('Admin/Products/AddProduct',[
            'carMakes' => $carMakes,
            'carModels' => $carModels,
            'carBodyStyles' => $carBodyStyles,
        ]);
    }

    /**
     * Handle an incoming add product request.
     *
     * @throws \Illuminate\Validation\ValidationException
     */
    public function create(Request $request): RedirectResponse
    {
        $request->validate([
            'item_number' => 'required|string|max:255',
            'nags_description' => 'required|string',
            'item_description' => 'required|string',
            'data_price' => 'required|string',
            'price_margin' => 'required|string',
            'price' => 'required|string',
            'quantity' => 'required|string',
            'stock' => 'required|integer',
            'year' => 'required',
            'year.*' => 'required|integer',
            'make' => 'required',
            'make.*' => 'required|integer',
            'model' => 'required',
            'model.*' => 'required|integer',
            'bodystyle' => 'required',
            'bodystyle.*' => 'required|integer',
        ]);

        $year = implode(',', $request->year);
        $validatedData['year'] = $year;

        $make = implode(',', $request->make);
        $validatedData['make'] = $make;

        $model = implode(',', $request->model);
        $validatedData['model'] = $model;

        $bodystyle = implode(',', $request->bodystyle);
        $validatedData['bodystyle'] = $bodystyle;

        $product = Product::create([
            'item_number' => $request->item_number,
            'nags_description' => $request->nags_description,
            'item_description' => $request->item_description,
            'data_price' => $request->data_price,
            'price_margin' => $request->price_margin,
            'price' => $request->price,
            'quantity' => $request->quantity,
            'stock' => $request->stock,
            'year' => $year,
            'make' => $make,
            'model' => $model,
            'bodystyle' => $bodystyle,
        ]);

        return Redirect::back();
    }

    /**
     * Edit Product.
     */
    public function edit($id)
    {
        $product = Product::find($id);

        $carMakes = CarMake::orderby('name','asc')->get();
        $carModels = CarModel::orderby('name','asc')->get();
        $carBodyStyles = CarBodyStyle::orderby('name','asc')->get();

        return Inertia::render('Admin/Products/EditProduct', [
            'product' => $product,
            'carMakes' => $carMakes,
            'carModels' => $carModels,
            'carBodyStyles' => $carBodyStyles,
        ]);
    }

    /**
     * Update the product by id.
     */
    public function update(Request $request, $id): RedirectResponse
    {
        $product = Product::findOrFail($id);

        $validatedData = $request->validate([
            'item_number' => 'required|string|max:255',
            'nags_description' => 'required|string|max:255',
            'item_description' => 'required|string|max:255',
            'data_price' => 'required|string|max:255',
            'price_margin' => 'required|string|max:255',
            'price' => 'required|string|max:255',
            'quantity' => 'required|integer',
            'stock' => 'required|integer',
            'year' => 'required',
            'year.*' => 'required|integer',
            'make' => 'required',
            'make.*' => 'required|integer',
            'model' => 'required',
            'model.*' => 'required|integer',
            'bodystyle' => 'required',
            'bodystyle.*' => 'required|integer',
        ]);

        if(is_array($validatedData['year'])) {
            $year = implode(',', $validatedData['year']);
            $validatedData['year'] = $year;
        }

        if(is_array($validatedData['make'])) {
            $make = implode(',', $validatedData['make']);
            $validatedData['make'] = $make;
        }

        if(is_array($validatedData['model'])) {
            $model = implode(',', $validatedData['model']);
            $validatedData['model'] = $model;
        }

        if(is_array($validatedData['bodystyle'])) {
            $bodystyle = implode(',', $validatedData['bodystyle']);
            $validatedData['bodystyle'] = $bodystyle;
        }

        $product->update($validatedData);

        return Redirect::back()->with('success', 'Product updated successfully')->with('product', $product);
    }

    /**
     * Delete Product.
     */
    public function delete($id)
    {

        $product = Product::find($id);

        if (!$product) {
            return Inertia::render('Admin/Products/AllProducts', [
                'status' => 'Product not found',
            ]);
        }

        $product->delete();
        $products = Product::all();

        return Redirect::back()->with('status', 'Product deleted successfully')->with('products', $products);
    }

    /**
     * Show the add car make view.
     */
    public function addmake(): Response {
        return Inertia::render('Admin/Products/Make/Add');
    }

    /**
     * Handle an incoming add car make request.
     *
     * @throws \Illuminate\Validation\ValidationException
     */
    public function createCarMake(Request $request): RedirectResponse
    {
        $request->validate([
            'name' => 'required|string',
            'year' => 'required',
            'year.*' => 'required|integer',
        ]);

        $year = implode(',', $request->year);
        $validatedData['year'] = $year;

        $carMake = CarMake::create([
            'name' => $request->name,
            'year' => $year,
        ]);

        return Redirect::back();
    }

    /**
     * Edit Car Make View.
     */
    public function editCarMake($id)
    {
        $carmake = CarMake::find($id);
        return Inertia::render('Admin/Products/Make/Edit', [
            'carmake' => $carmake
        ]);
    }

    /**
     * Update the Car Make by id.
     */
    public function updateCarMake(Request $request, $id): RedirectResponse
    {
        $carmake = CarMake::findOrFail($id);

        $validatedData = $request->validate([
            'name' => 'required|string',
            'year' => 'required',
            'year.*' => 'required|integer',
        ]);

        if(is_array($validatedData['year'])) {
            $year = implode(',', $validatedData['year']);
            $validatedData['year'] = $year;
        }

        $carmake->update($validatedData);

        return Redirect::back()->with('success', 'Car Make updated successfully')->with('carmake', $carmake);
    }

    /**
     * Show the All Car Make view.
     */
    public function allMakes(Request $request): Response {
        $perPage = $request->input('per_page', 10);
        $carMakes = CarMake::paginate($perPage);

        return Inertia::render('Admin/Products/Make/All', [
            'carMakes' => $carMakes,
            'per_page' => $perPage,
        ]);
    }


    /**
     * Delete Car Make.
     */
    public function deleteCarMake($id)
    {

        $carMake = CarMake::find($id);

        if (!$carMake) {
            return Inertia::render('Admin/Products/Make/All', [
                'status' => 'Car Make not found',
            ]);
        }

        $carMake->delete();
        $carmakes = CarMake::orderby('name','asc')->get();

        return Redirect::back()->with('status', 'Car Make deleted successfully')->with('carmakes', $carmakes);
    }

    /**
     * Show the All Car Model view.
     */
    public function allModels(Request $request): Response {
        $perPage = $request->input('per_page', 10);
        $carMakes = CarMake::orderby('name','asc')->get();
        $carModels = CarModel::paginate($perPage);

        return Inertia::render('Admin/Products/Model/All', [
            'carModels' => $carModels,
            'carMakes' => $carMakes,
            'per_page' => $perPage,
        ]);

        return Inertia::render('Admin/Products/Model/All');
    }

    public function addModel(): Response {
        $carMakes = CarMake::orderby('name','asc')->get();
        return Inertia::render('Admin/Products/Model/Add',[
            'carMakes' => $carMakes
        ]);
    }

    /**
     * Handle an incoming add car Model request.
     *
     * @throws \Illuminate\Validation\ValidationException
     */
    public function createCarModel(Request $request): RedirectResponse
    {
        $request->validate([
            'name' => 'required|string',
            'year' => 'required',
            'year.*' => 'required|integer',
            'make' => 'required',
            'make.*' => 'required|integer',
        ]);

        $year = implode(',', $request->year);

        $make = implode(',', $request->make);

        $carMake = CarModel::create([
            'name' => $request->name,
            'year' => $year,
            'make' => $make,
        ]);

        return Redirect::back();
    }

    /**
     * Edit Car Model View.
     */
    public function editCarModel($id)
    {
        $carMakes = CarMake::orderby('name','asc')->get();
        $carmodel = CarModel::find($id);
        return Inertia::render('Admin/Products/Model/Edit', [
            'carmodel' => $carmodel,
            'carMakes' => $carMakes
        ]);
    }

    /**
     * Update the Car Model by id.
     */
    public function updateCarModel(Request $request, $id): RedirectResponse
    {
        $carmodel = CarModel::findOrFail($id);

        $validatedData = $request->validate([
            'name' => 'required|string',
            'year' => 'required',
            'year.*' => 'required|integer',
            'make' => 'required',
            'make.*' => 'required|integer',
        ]);

        if(is_array($validatedData['year'])) {
            $year = implode(',', $validatedData['year']);
            $validatedData['year'] = $year;
        }

        if(is_array($validatedData['make'])) {
            $make = implode(',', $validatedData['make']);
            $validatedData['make'] = $make;
        }

        $carmodel->update($validatedData);

        return Redirect::back()->with('success', 'Car Model updated successfully')->with('carmodel', $carmodel);
    }

    /**
     * Delete Car Model.
     */
    public function deleteCarModel($id)
    {

        $carModel = CarModel::find($id);

        if (!$carModel) {
            return Inertia::render('Admin/Products/Model/All', [
                'status' => 'Car Model not found',
            ]);
        }

        $carModel->delete();
        $carmodels = CarModel::all();

        return Redirect::back()->with('status', 'Car Model deleted successfully')->with('carmodels', $carmodels);
    }

    /**
     * Show the All Car Body Styles view.
     */
    public function allBodyStyles(Request $request): Response {
        $perPage = $request->input('per_page', 10);
        $carMakes = CarMake::orderby('name','asc')->get();
        $carModels = CarModel::orderby('name','asc')->get();
        $carBodyStyles = CarBodyStyle::paginate($perPage);

        return Inertia::render('Admin/Products/BodyStyle/All', [
            'carModels' => $carModels,
            'carMakes' => $carMakes,
            'carBodyStyles' => $carBodyStyles,
            'per_page' => $perPage,
        ]);
    }

    public function addBodyStyle(): Response {
        $carMakes = CarMake::orderby('name','asc')->get();
        $carModels = CarModel::orderby('name','asc')->get();
        return Inertia::render('Admin/Products/BodyStyle/Add',[
            'carMakes' => $carMakes,
            'carModels' => $carModels
        ]);
    }

    /**
     * Handle an incoming add car body style request.
     *
     * @throws \Illuminate\Validation\ValidationException
     */
    public function createCarBodyStyle(Request $request): RedirectResponse
    {
        $request->validate([
            'name' => 'required|string',
            'year' => 'required',
            'year.*' => 'required|integer',
            'make' => 'required',
            'make.*' => 'required|integer',
            'model' => 'required',
            'model.*' => 'required|integer',
        ]);

        $year = implode(',', $request->year);
        $validatedData['year'] = $year;

        $make = implode(',', $request->make);
        $validatedData['make'] = $make;

        $model = implode(',', $request->model);
        $validatedData['model'] = $model;

        $carMake = CarBodyStyle::create([
            'name' => $request->name,
            'year' => $year,
            'model' => $model,
            'make' => $make,
        ]);

        return Redirect::back();
    }

    /**
     * Edit Car Model View.
     */
    public function editCarBodyStyle($id)
    {
        $carMakes = CarMake::orderby('name','asc')->get();
        $carModels = CarModel::orderby('name','asc')->get();
        $carBodyStyle = CarBodyStyle::find($id);
        return Inertia::render('Admin/Products/BodyStyle/Edit', [
            'carBodyStyle' => $carBodyStyle,
            'carModels' => $carModels,
            'carMakes' => $carMakes
        ]);
    }

    /**
     * Update the Car Model by id.
     */
    public function updateCarBodyStyle(Request $request, $id): RedirectResponse
    {
        $carBodyStyle = CarBodyStyle::findOrFail($id);

        $validatedData = $request->validate([
            'name' => 'required|string',
            'year' => 'required',
            'year.*' => 'required|integer',
            'make' => 'required',
            'make.*' => 'required|integer',
            'model' => 'required',
            'model.*' => 'required|integer',
        ]);

        if(is_array($validatedData['year'])) {
            $year = implode(',', $validatedData['year']);
            $validatedData['year'] = $year;
        }

        if(is_array($validatedData['make'])) {
            $make = implode(',', $validatedData['make']);
            $validatedData['make'] = $make;
        }

        if(is_array($validatedData['model'])) {
            $model = implode(',', $validatedData['model']);
            $validatedData['model'] = $model;
        }

        $carBodyStyle->update($validatedData);

        return Redirect::back()->with('success', 'Car Body Style updated successfully')->with('carBodyStyle', $carBodyStyle);
    }

    /**
     * Delete Car Body Style.
     */
    public function deleteCarBodyStyle($id)
    {

        $carBodyStyle = CarBodyStyle::find($id);

        if (!$carBodyStyle) {
            return Inertia::render('Admin/Products/BodyStyle/All', [
                'status' => 'Car Body Style not found',
            ]);
        }

        $carBodyStyle->delete();
        $carBodyStyles = CarBodyStyle::all();

        return Redirect::back()->with('status', 'Car Body Style deleted successfully')->with('carBodyStyles', $carBodyStyles);
    }

    /**
     * Import Products
     */
    public function import() {
        return Inertia::render('Admin/Products/Import');
    }

    /**
     * Store CSV imported file
     */
    public function importSave(Request $request) {

        set_time_limit(30000);

        $validator = Validator::make($request->all(), [
            'csv_file' => 'required|mimes:csv,txt|max:8192', // Adjust max size as needed
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        // Parse the CSV file
        $csvData = array_map('str_getcsv', file($request->file('csv_file')));

        // Remove header row if necessary
        $header = array_shift($csvData);

        $counter = 1;
        // Insert data into database
        foreach ($csvData as $row) {
            $item_number = trim($row[0]);
            if(!empty($item_number)) {

                $item_description = trim($row[1]);
                $data_price = str_replace(',','',(str_replace('$','',trim($row[2]))));
                $stock = trim($row[3]) == 'Please Call' ? 2 : 1;
                $year = trim($row[4]);
                $makeName = trim($row[5]);
                $modelName = trim($row[6]);
                $bodystyleName = trim($row[7]);

                // Find Make
                $makeDetails = CarMake::where('name',$makeName)->first();
                if($makeDetails) {
                    $make = $makeDetails['id'];
                    $makeYear = $makeDetails['year'];

                    $checkYear = $this->compare_data_string($year,$makeYear);
                    var_dump($checkYear);
                    if($checkYear) {
                        // var_dump('Make Update year - '.$make.' -- '.$makeName);
                        $makeYearExp = explode(',',$makeYear);
                        $makeYearExp[] = $year;
                        $makeYearUpdate = implode(',',$makeYearExp);
                        CarMake::where('id', $make)->update(['year' => $makeYearUpdate]);
                    }
                    else {
                        // var_dump('Make Year already exists - '.$makeYear.', '.$make.' -- '.$makeName);
                    }
                }
                else {
                    $createdCarMake = CarMake::create([
                        'name' => $makeName,
                        'year' => $year,
                    ]);
                    $make = $createdCarMake['id'];
                }

                // Find Model
                $modelDetails = CarModel::where('name',$modelName)->first();
                if($modelDetails) {
                    $model = $modelDetails['id'];
                    $modelYear = $modelDetails['year'];
                    $modelMake = $modelDetails['make'];

                    $checkModelYear = $this->compare_data_string($year,$modelYear);
                    var_dump($checkModelYear);
                    if($checkModelYear) {
                        // var_dump('Model Update year - '.$model.' -- '.$modelName);
                        // $modelYearUpdate = $modelYear.','.$year;

                        $modelYearExp = explode(',',$modelYear);
                        $modelYearExp[] = $year;
                        $modelYearUpdate = implode(',',$modelYearExp);

                        CarModel::where('id', $model)->update(['year' => $modelYearUpdate]);
                    }
                    else {
                        // var_dump('Model Year already exists - '.$modelYear.', '.$model.' -- '.$modelName);
                    }

                    $checkModelMake = $this->compare_data_string($make,$modelMake);
                    var_dump($checkModelMake);
                    if($checkModelMake) {
                        // var_dump('Model Update make - '.$modelMake.' - '.$model.' - '.$make.' -- '.$modelName);
                        // $modelMakeUpdate = $modelMake.','.$make;

                        $modelMakeExp = explode(',',$modelMake);
                        $modelMakeExp[] = $make;
                        $modelMakeUpdate = implode(',',$modelMakeExp);

                        CarModel::where('id', $model)->update(['make' => $modelMakeUpdate]);
                    }
                    else {
                        // var_dump('Make already exists - '.$modelMake.', '.$model.' - '.$make.' -- '.$modelName);
                    }
                }
                else {
                    $createdCarModel = CarModel::create([
                        'name' => $modelName,
                        'make' => $make,
                        'year' => $year,
                    ]);
                    $model = $createdCarModel['id'];
                }


                // Find BodyStyle
                $bodystyleDetails = CarBodyStyle::where('name',$bodystyleName)->first();
                if($bodystyleDetails) {
                    $bodystyle = $bodystyleDetails['id'];
                    $bodystyleYear = $bodystyleDetails['year'];
                    $bodystyleMake = $bodystyleDetails['make'];
                    $bodystyleModel = $bodystyleDetails['model'];

                    $checkBodyStyleYear = $this->compare_data_string($year,$bodystyleYear);
                    var_dump($checkBodyStyleYear);
                    if($checkBodyStyleYear) {
                        // var_dump('Body Style Update year - '.$model.' -- '.$modelName);
                        // $bodystyleYearUpdate = $modelYear.','.$year;

                        $bodystyleYearExp = explode(',',$bodystyleYear);
                        $bodystyleYearExp[] = $year;
                        $bodystyleYearUpdate = implode(',',$bodystyleYearExp);

                        CarBodyStyle::where('id', $bodystyle)->update(['year' => $bodystyleYearUpdate]);
                    }
                    else {
                        // var_dump('Body Style Year already exists - '.$modelYear.', '.$model.' -- '.$modelName);
                    }

                    $checkBodystyleMake = $this->compare_data_string($make,$bodystyleMake);
                    var_dump($checkBodystyleMake);
                    if($checkBodystyleMake) {
                        // var_dump('Bodystyle Update make - '.$bodystyleMake.' - '.$model.' - '.$make.' -- '.$modelName);

                        $bodystyleMakeExp = explode(',',$bodystyleMake);
                        $bodystyleMakeExp[] = $make;
                        $bodystyleMakeUpdate = implode(',',$bodystyleMakeExp);

                        CarBodyStyle::where('id', $bodystyle)->update(['make' => $bodystyleMakeUpdate]);
                    }
                    else {
                        // var_dump('Bodystyle make already exists - '.$modelMake.', '.$model.' - '.$make.' -- '.$modelName);
                    }

                    $checkBodystyleModel = $this->compare_data_string($model,$bodystyleModel);
                    var_dump($checkBodystyleModel);
                    if($checkBodystyleModel) {
                        // var_dump('Bodystyle Update model - '.$bodystyleModel.' - '.$model.' - '.$make.' -- '.$modelName);

                        $bodystyleModelExp = explode(',',$bodystyleModel);
                        $bodystyleModelExp[] = $model;
                        $bodystyleModelUpdate = implode(',',$bodystyleModelExp);

                        CarBodyStyle::where('id', $bodystyle)->update(['model' => $bodystyleModelUpdate]);
                    }
                    else {
                        // var_dump('Bodystyle model already exists - '.$modelMake.', '.$model.' - '.$make.' -- '.$modelName);
                    }
                }
                else {
                    $createdCarBodyStyle = CarBodyStyle::create([
                        'name' => $bodystyleName,
                        'make' => $make,
                        'model' => $model,
                        'year' => $year,
                    ]);
                    $bodystyle = $createdCarBodyStyle['id'];
                }

                var_dump($make);
                var_dump($model);
                var_dump($bodystyle);

                $nags_description = trim($row[9]);
                $price_margin = trim($row[10]);
                $quantity = trim($row[11]);

                if(empty($nags_description)) {
                    $nags_description = $makeName.' '.$modelName.' '.$year;
                }

                if(empty($price_margin)) {
                    $price_margin = 10;
                }

                if(empty($quantity)) {
                    $quantity = '';
                }

                $price = $data_price + (($data_price * $price_margin) / 100);
                $price = number_format($price, 2);

                var_dump($data_price);
                var_dump($price_margin);
                var_dump($price);

                // Find Product
                $productDetails = Product::where('item_number',$item_number)->first();
                if($productDetails) {

                    $productID = $productDetails['id'];
                    $productYear = $productDetails['year'];
                    $productMake = $productDetails['make'];
                    $productModel = $productDetails['model'];
                    $productBodystyle = $productDetails['bodystyle'];

                    $checkProductYear = $this->compare_data_string($year,$productYear);
                    if($checkProductYear) {
                        $productYearExp = explode(',',$productYear);
                        $productYearExp[] = $year;
                        $productYearUpdate = implode(',',$productYearExp);
                    }
                    else {
                        $productYearUpdate = $year;
                    }

                    $checkProductMake = $this->compare_data_string($make,$productMake);
                    if($checkProductMake) {
                        $productMakeExp = explode(',',$productMake);
                        $productMakeExp[] = $year;
                        $productMakeUpdate = implode(',',$productMakeExp);
                    }
                    else {
                        $productMakeUpdate = $make;
                    }

                    $checkProductModel = $this->compare_data_string($model,$productModel);
                    if($checkProductModel) {
                        $productModelExp = explode(',',$productModel);
                        $productModelExp[] = $year;
                        $productModelUpdate = implode(',',$productModelExp);
                    }
                    else {
                        $productModelUpdate = $model;
                    }

                    $checkProductBodystyle = $this->compare_data_string($bodystyle,$productBodystyle);
                    if($checkProductBodystyle) {
                        $productBodystyleExp = explode(',',$productBodystyle);
                        $productBodystyleExp[] = $year;
                        $productBodystyleUpdate = implode(',',$productBodystyleExp);
                    }
                    else {
                        $productBodystyleUpdate = $bodystyle;
                    }

                    $productDetails->update([
                        'item_number' => $item_number,
                        'nags_description' => $nags_description,
                        'item_description' => $item_description,
                        'data_price' => $data_price,
                        'price_margin' => $price_margin,
                        'price' => $price,
                        'quantity' => $quantity,
                        'stock' => $stock,
                        'year' => $productYearUpdate,
                        'make' => $productMakeUpdate,
                        'model' => $productModelUpdate,
                        'bodystyle' => $productBodystyleUpdate,
                    ]);

                    var_dump('Product Updated - '.$productDetails->id);
                }
                else {
                    $newproduct = Product::create([
                        'item_number' => $item_number,
                        'nags_description' => $nags_description,
                        'item_description' => $item_description,
                        'data_price' => $data_price,
                        'price_margin' => $price_margin,
                        'price' => $price,
                        'quantity' => $quantity,
                        'stock' => $stock,
                        'year' => $year,
                        'make' => $make,
                        'model' => $model,
                        'bodystyle' => $bodystyle,
                    ]);
                    var_dump('Product Created - '.$newproduct->id);
                }

                $counter++;
            }
            else {
                var_dump("Empty item_number");
            }
        }

        var_dump($counter);

        exit();
    }

    /**
     * Multi Select Process
     */
    public function multiSelectProcesses(Request $request) {
        var_dump($request->products);
        var_dump($request->action);
        if($request->action == 'instock') {
            return Redirect::back();
        }

        if($request->action == 'delete') {
            return Redirect::back();
        }
        exit();
    }

    /**
     * Compare string value with string with comma
     */
    public function compare_data_string($compare,$data) {
        $dataArr = explode(',',$data);
        if(in_array($compare,$dataArr)) {
            return false;
        }
        return true;
    }

}
