<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\Auth\LoginRequest;
use App\Http\Requests\ProfileUpdateRequest;
use App\Models\Address;
use App\Providers\RouteServiceProvider;
use Illuminate\Auth\Events\Registered;
use Illuminate\Http\RedirectResponse;

use Illuminate\Http\Request;
use Illuminate\Validation\Rules;
use Illuminate\Validation\Rule;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Redirect;
use Inertia\Inertia;
use Inertia\Response;

use App\Models\Admin;
use App\Models\User;

class UsersController extends Controller
{
    /**
     * Show the All Users view.
     */
    public function show(Request $request): Response
    {
        $perPage = $request->input('per_page', 10);
        $users = User::paginate($perPage);

        return Inertia::render('Admin/Users/AllUsers', [
            'users' => $users,
            'per_page' => $perPage,
        ]);
    }

    /**
     * Show the add user view.
     */
    public function add(): Response
    {
        return Inertia::render('Admin/Users/AddUser');
    }

    /**
     * Handle an incoming registration request.
     *
     * @throws \Illuminate\Validation\ValidationException
     */
    public function create(Request $request): RedirectResponse
    {
        $request->validate([
            'name' => 'required|string|max:255',
            'email' => 'required|string|lowercase|email|max:255|unique:'.User::class,
            'password' => ['required', 'confirmed', Rules\Password::defaults()],
            'company' => 'required|string',
            'address1' => 'required|string',
            'city' => 'required|string',
            'state' => 'required|string',
            'postal' => 'required|string',
            'country' => 'required|string',
            'phone' => 'required|string',
        ]);

        if($request->type == 'admin') {
            $user = Admin::create([
                'name' => $request->name,
                'email' => $request->email,
                'password' => Hash::make($request->password),
                'company' => $request->company,
                'address1' => $request->address1,
                'address2' => $request->address,
                'city' => $request->city,
                'state' => $request->state,
                'postal' => $request->postal,
                'country' => $request->country,
                'phone' => $request->phone,
                'fax' => $request->fax,
            ]);
        }
        else {
            $user = User::create([
                'name' => $request->name,
                'email' => $request->email,
                'password' => Hash::make($request->password),
                'company' => $request->company,
                'address1' => $request->address1,
                'address2' => $request->address,
                'city' => $request->city,
                'state' => $request->state,
                'postal' => $request->postal,
                'country' => $request->country,
                'phone' => $request->phone,
                'fax' => $request->fax,
            ]);
        }

        event(new Registered($user));

        return Redirect::back()->with('add', 'User added successfully');
    }

    /**
     * Edit the user by id.
     */
    public function edit($id)
    {
        $user = User::find($id);
        return Inertia::render('Admin/Users/EditUser', [
            'user' => $user
        ]);
    }

    /**
     * Update the user by id.
     */
    public function update(Request $request, $id): RedirectResponse
    {
        $user = User::findOrFail($id);
        $validatedData = $request->validate([
            'name' => 'required|string|max:255',
            'email' => [
                'required',
                'email',
                'max:255',
                // Unique email, except for the user being updated
                Rule::unique('users')->ignore($user->id),
            ],
            'company' => ['required', 'string', 'max:255'],
            'address1' => ['required', 'string', 'max:255'],
            'city' => ['required', 'string', 'max:255'],
            'state' => ['required', 'string', 'max:255'],
            'postal' => ['required', 'string', 'max:255'],
            'country' => ['required', 'string', 'max:255'],
            'phone' => ['required', 'string', 'max:255'],
        ]);

        if(!$request->address2) {
            $validatedData['address2'] = '';
        }

        if(!$request->fax) {
            $validatedData['fax'] = '';
        }

        $user->update($validatedData);

        return Redirect::back()->with('success', 'User updated successfully')->with('updatedUser', $user);
    }

    /**
     * Handle an incoming authentication request.
     */
    public function store(LoginRequest $request): RedirectResponse
    {
        $request->authenticate();

        $request->session()->regenerate();

        return redirect()->intended(RouteServiceProvider::HOME);
    }

    /**
     * Delete user.
     */
    public function delete($id)
    {

        $user = User::find($id);

        if (!$user) {
            return Inertia::render('Admin/Users/AllUsers', [
                'status' => 'User not found',
            ]);
        }

        $user->delete();
        $users = User::all();

        return Redirect::back()->with('success', 'User deleted successfully')->with('users', $users);
    }

    /**
     * User Addresses
     */
    public function showAddresses($id, Request $request): Response {
        $user = User::find($id);
        $addresses = $user->addresses;

        return Inertia::render('Admin/Users/UserAddresses', [
            'addresses' => $addresses,
            'user' => $user
        ]);
    }

    /**
     * User Address Add
     */
    public function addAddress($id): Response {
        return Inertia::render('Admin/Users/AddAddress');
    }

    /**
     * User Address Create
     *
     * @throws \Illuminate\Validation\ValidationException
     */
    public function createAddress($id, Request $request): RedirectResponse
    {
        $user = User::find($id);
        if($user) {
            $request->validate([
                'name' => 'required|string|max:255',
                'company' => 'string',
                'contact' => 'string',
                'phone' => 'string',
                'fax' => 'string',
                'address1' => 'required|string',
                'address2' => 'required|string',
                'city' => 'required|string',
                'state' => 'required|string',
                'zip' => 'required|string',
                'country' => 'required|string',
            ]);

            $user->addresses()->create([
                'name' => $request->name,
                'user_id' => $id,
                'company' => $request->company,
                'contact' => $request->contact,
                'phone' => $request->phone,
                'fax' => $request->fax,
                'address1' => $request->address1,
                'address2' => $request->address2,
                'city' => $request->city,
                'state' => $request->state,
                'zip' => $request->zip,
                'country' => $request->country,
            ]);

            return Redirect::back()->with('status', 'User address added successfully');
        }
        else {
            return Redirect::back()->with('status', 'User not found');
        }
    }

    /**
     * User Address Edit
     */
    public function editAddress($id, $aid) {
        $user = User::find($id);
        $address = Address::find($aid);
        return Inertia::render('Admin/Users/EditAddress', [
            'user' => $user,
            'address' => $address
        ]);
    }

    /**
     * Update user address by id.
     */
    public function updateAddress(Request $request, $id, $aid): RedirectResponse
    {
        $address = Address::findOrFail($aid);
        $validatedData = $request->validate([
            'name' => ['required', 'string', 'max:255'],
            'company' => ['max:255'],
            'contact' => ['max:255'],
            'phone' => ['max:255'],
            'address1' => ['required', 'string', 'max:255'],
            'city' => ['required', 'string', 'max:255'],
            'state' => ['required', 'string', 'max:255'],
            'zip' => ['required', 'string', 'max:255'],
            'country' => ['required', 'string', 'max:255'],
        ]);

        $address->update($validatedData);

        return Redirect::back()->with('success', 'User address updated successfully')->with('address', $address);
    }
}
